@@ -1,6 +1,6 @@
 library(testthat)
 
-credential_1  <- retrieve_credential_testing(999L)
+credential_1  <- retrieve_credential_testing("dag")
 credential_2  <- retrieve_credential_testing()
 update_expectation  <- FALSE
 
@@ -23,7 +23,6 @@ test_that("smoke test", {
     )
   expect_type(returned_object_2, "list")
 })
-
 test_that("with-dags", {
   testthat::skip_on_cran()
   path_expected_user        <- "test-data/specific-redcapr/users-export/with-dags--user.R"
@@ -37,15 +36,43 @@ test_that("with-dags", {
       verbose     = FALSE
     )
 
+  d_user <-
+    returned_object$data_user |>
+    dplyr::filter(username == "unittestphifree") |>
+    dplyr::select(
+      -email
+    )
+
+  # Check the group id exists
+  expect_true(!is.na(d_user$data_access_group_id))
+
+  # For these two specific servers, check the exact value of the id
+  if (credential_1$redcap_uri == "https://redcap-dev-2.ouhsc.edu/redcap/api/") {
+    expect_equal(d_user$data_access_group_id, "20")
+  } else if (credential_1$redcap_uri == "https://bbmc.ouhsc.edu/redcap/api/") {
+    expect_equal(d_user$data_access_group_id, "331")
+  }
+
+  # Drop the ID because it won't match other servers
+  d_user <-
+    d_user |>
+    dplyr::select(
+      -data_access_group_id
+    )
+
+  d_user_form <-
+    returned_object$data_user_form |>
+    dplyr::filter(username == "unittestphifree")
+
   if (update_expectation) {
-    save_expected(returned_object$data_user     , path_expected_user     )
-    save_expected(returned_object$data_user_form, path_expected_user_form)
+    save_expected(d_user     , path_expected_user     )
+    save_expected(d_user_form, path_expected_user_form)
   }
   expected_data_user      <- retrieve_expected(path_expected_user     )
   expected_data_user_form <- retrieve_expected(path_expected_user_form)
 
-  expect_equal(returned_object$data_user     , expected=expected_data_user     , label="The returned data.frame should be correct", ignore_attr = TRUE) # dput(returned_object$data_user);
-  expect_equal(returned_object$data_user_form, expected=expected_data_user_form, label="The returned data.frame should be correct", ignore_attr = TRUE) # dput(returned_object$data_user_form)
+  expect_equal(d_user     , expected=expected_data_user     , label="The returned data.frame should be correct", ignore_attr = TRUE) # dput(returned_object$data_user);
+  expect_equal(d_user_form, expected=expected_data_user_form, label="The returned data.frame should be correct", ignore_attr = TRUE) # dput(returned_object$data_user_form)
   expect_equal(returned_object$status_code, expected=200L)
   expect_equal(returned_object$raw_text, expected="", ignore_attr = TRUE) # dput(returned_object$raw_text)
   expect_match(returned_object$outcome_message, regexp=expected_outcome_message, perl=TRUE)
@@ -67,15 +94,26 @@ test_that("without DAGs", {
       verbose     = FALSE
     )
 
+  d_user <-
+    returned_object$data_user |>
+    dplyr::filter(username == "unittestphifree") |>
+    dplyr::select(
+      -email
+    )
+
+  d_user_form <-
+    returned_object$data_user_form |>
+    dplyr::filter(username == "unittestphifree")
+
   if (update_expectation) {
-    save_expected(returned_object$data_user     , path_expected_user     )
-    save_expected(returned_object$data_user_form, path_expected_user_form)
+    save_expected(d_user     , path_expected_user     )
+    save_expected(d_user_form, path_expected_user_form)
   }
   expected_data_user      <- retrieve_expected(path_expected_user     )
   expected_data_user_form <- retrieve_expected(path_expected_user_form)
 
-  expect_equal(returned_object$data_user     , expected=expected_data_user     , label="The returned data.frame should be correct", ignore_attr = TRUE) # dput(returned_object$data_user);
-  expect_equal(returned_object$data_user_form, expected=expected_data_user_form, label="The returned data.frame should be correct", ignore_attr = TRUE) # dput(returned_object$data_user_form)
+  expect_equal(d_user     , expected=expected_data_user     , label="The returned data.frame should be correct", ignore_attr = TRUE) # dput(returned_object$data_user);
+  expect_equal(d_user_form, expected=expected_data_user_form, label="The returned data.frame should be correct", ignore_attr = TRUE) # dput(returned_object$data_user_form)
   expect_equal(returned_object$status_code, expected=200L)
   expect_equal(returned_object$raw_text, expected="", ignore_attr = TRUE) # dput(returned_object$raw_text)
   expect_match(returned_object$outcome_message, regexp=expected_outcome_message, perl=TRUE)
